import { Body, Controller, Get, Post } from '@nestjs/common';
import { TranslateService } from './translate.service';
import { Auth } from '@/common/decorators/auth.decorator';
import { ApiTags, ApiOperation, ApiResponse } from '@nestjs/swagger';
import { TranslateReqDto } from './dto/req/translateReq.dto';
import { TranslateResDto } from './dto/res/translateRes.dto';

@ApiTags('translate')
@Controller('translate')
export class TranslateController {
  constructor(private readonly translateService: TranslateService) {}

  // 获取翻译支持的语言
  @Get('languages')
  @ApiOperation({ summary: '获取翻译支持的语言' })
  @ApiResponse({
    status: 200,
    description: '成功返回支持的语言列表',
    example: {
      source: [{ key: 'AR', language: 'Arabic', name: '阿拉伯语' }],
      target: [{ key: 'AR', language: 'Arabic', name: '阿拉伯语' }],
    },
  })
  @Auth()
  async getLanguages(): Promise<{ source: object[]; target: object[] }> {
    return await this.translateService.getLanguages();
  }

  // 翻译文本
  @Post('text')
  @ApiOperation({ summary: '翻译文本' })
  @ApiResponse({
    status: 200,
    description: '成功返回翻译结果',
    example: {
      source: 'EN',
      text: '要翻译的文本',
    },
  })
  @Auth()
  async translateText(
    @Body() translateDto: TranslateReqDto,
  ): Promise<TranslateResDto> {
    return await this.translateService.translateText(translateDto);
  }
}
