import {
  DEEPL_SOURCE_LANGUAGES,
  DEEPL_TARGET_LANGUAGES,
} from '@/common/utils/constants';
import { Injectable } from '@nestjs/common';
import { TranslateReqDto } from './dto/req/translateReq.dto';
import { TranslateResDto } from './dto/res/translateRes.dto';
import { axiosPostRequest } from '@/common/utils/requests/request';
import { config } from '@/config';
import { BadRequestError } from '@/common/exception/badRequest/BadRequestError';

@Injectable()
export class TranslateService {
  constructor() {}

  // 获取翻译支持的语言
  async getLanguages(): Promise<{ source: object[]; target: object[] }> {
    return {
      source: DEEPL_SOURCE_LANGUAGES,
      target: DEEPL_TARGET_LANGUAGES,
    };
  }

  // 翻译文本
  async translateText(translateDto: TranslateReqDto): Promise<TranslateResDto> {
    const result = await axiosPostRequest(
      `${config.deepl.endpoint}/v2/translate`,
      {
        text: [translateDto.text],
        target_lang: translateDto.target,
      },
      {
        headers: {
          'Content-Type': 'application/json',
          Authorization: `DeepL-Auth-Key ${config.deepl.secret}`,
        },
      },
    );

    const { translations } = result?.data;

    if (!translations?.length) {
      throw BadRequestError.default('翻译失败');
    }

    const [{ detected_source_language: source, text }] = translations;

    return { source, text };
  }
}
